@@ -521,6 +521,32 @@ class LayersControl(Control):
     _model_name = Unicode('LeafletLayersControlModel').tag(sync=True)
 
 
+class SplitMapControl(Control):
+    _view_name = Unicode('LeafletSplitMapControlView').tag(sync=True)
+    _model_name = Unicode('LeafletSplitMapControlModel').tag(sync=True)
+    _draw_callbacks = Instance(CallbackDispatcher, ())
+
+    leftLayer = Instance(TileLayer).tag(sync=True, **widget_serialization)
+    rightLayer = Instance(TileLayer).tag(sync=True, **widget_serialization)
+
+    @default('leftLayer')
+    def _default_leftLayer(self):
+        return TileLayer()
+
+    @default('rightLayer')
+    def _default_rightLayer(self):
+        return TileLayer()
+
+    def __init__(self, **kwargs):
+        super(SplitMapControl, self).__init__(**kwargs)
+        self.on_msg(self._handle_leaflet_event)
+
+    def _handle_leaflet_event(self, _, content, buffers):
+        if content.get('event', '') == 'dividermove':
+            event = content.get('event')
+            self.x = event.x
+
+
 class DrawControl(Control):
     _view_name = Unicode('LeafletDrawControlView').tag(sync=True)
     _model_name = Unicode('LeafletDrawControlModel').tag(sync=True)
